#####################################
#Block to read in correlation matrix
#	This block reads the pairwise correlation matrix into a 2-dimensional hash (%corr).
#	The keys of the hash are always such that the first sorted gene identifier is the first key.
#	The array @genes contains all genes in the matrix.
#	Nathan Clark nclark@pitt.edu 9/8/2011
#####################################

my $corr_file = "erc.tsv";  #Change this filename to match your input file.


my %corr; #2-dimensional hash, first key is always first in sort.
if (!open(RFILE, "$corr_file")) {
	die "Can't open ERC results file: $corr_file\n$! \n";
}
print STDERR "Reading correlation file: $corr_file\n";
my $count = 0;
my $past = 0;
my @genes = split /\t/ , <RFILE>;
for (my $i = 1; $i < scalar @genes; $i++) {
	my @e = split /\t/ , <RFILE>;
	chomp $e[-1];
	die "Non-consecutive.\ni $i\n@e\n" unless scalar @e == $past + 1;
	$past++;
	for (my $j = 0; $j < $i; $j++) {
		next unless ($e[$j] =~ /\d/);
		my ($g1 , $g2) = sort ($genes[$i] , $genes[$j]);
		$corr{$g1}->{$g2} = $e[$j];
		$count++;
	}
}
close RFILE;
print STDERR "Finished reading correlation file.\nNumber of genes  = ",scalar @genes,"\nNumber of values = $count\n";




exit;
